#
# spec file for package python-pkginfo
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-pkginfo
Version:        1.11.1
Release:        1.1
Summary:        Python package for querying metadatdata from sdists/bdists/installed packages
License:        MIT
Group:          Development/Languages/Python
URL:            https://pypi.python.org/pypi/pkginfo/
Source:         https://files.pythonhosted.org/packages/source/p/pkginfo/pkginfo-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.7}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-setuptools
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module wheel}
# /SECTION
%python_subpackages

%description
This package provides an API for querying the distutils metadata written in
the PKG-INFO file inside a source distriubtion (an sdist) or a
binary distribution (e.g., created by running bdist_egg).  It can
also query the EGG-INFO directory of an installed distribution, and
the *.egg-info stored in a "development checkout"
(e.g, created by running setup.py develop).

%prep
%setup -q -n pkginfo-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%python_clone -a %{buildroot}%{_bindir}/pkginfo

%check
%pytest

%post
%python_install_alternative pkginfo

%postun
%python_uninstall_alternative pkginfo

%files %{python_files}
%license LICENSE.txt
%doc README.txt CHANGES.txt TODO.txt
%python_alternative %{_bindir}/pkginfo
%{python_sitelib}/pkginfo
%{python_sitelib}/pkginfo-%{version}.dist-info

%changelog
* Thu Jun 20 2024 Dirk Müller <dmueller@suse.com>
- update to 1.11.1:
  * Updated typing stubs, adding additionaly checks to 'tox -e
    mypy' to verify that they don't drift in the future.
* Mon Jun  3 2024 Dirk Müller <dmueller@suse.com>
- update to 1.11.0:
  * Add support for Python 3.13.
  * Drop support for Python 3.7.
  * Emit warnings for distributions parsed with unknown metadata
    versions, or metadata versions newer than highest supported
    version.
  * Improve exception message when failing to find a valid 'PKG-
    INFO' file within an 'sdist' archive.  LP #2064652.
* Sat Mar 16 2024 Dirk Müller <dmueller@suse.com>
- update to 1.10.0:
  * Add support for Python 3.11 and 3.12.
  * Drop support for Python 3.6.
  * Declare explicit testing dependency on 'wheel'.
  * Add support for Metadata 2.3.
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 Matej Cepl <mcepl@suse.com>
- Make calling of %%{sle15modernpython} optional.
* Fri Jan 20 2023 Elisei Roca <eroca@suse.com>
- Update to version 1.9.6
    1.9.6 (2023-01-08)
  - -----------------
  - Fix various typos in docs / docstrings.  LP #2002232.
    1.9.5 (2023-01-06)
  - -----------------
  - Add stricter typing checks, matching those used in 'twine'.
  - Fix typing errors / gaps reported from 'twine' CI failure.  LP #2002104.
    1.9.4 (2023-01-05)
  - -----------------
  - Fix packaging of stub file for Python typing support.
    1.9.3 (2023-01-03)
  - -----------------
  - Added stub files for Python typing support;  verify using 'mypy'. LP #1876591.
    1.9.2 (2022-11-29)
  - -----------------
  - Drop "universal" wheel support (should be redundant with
    'python_requires >= 3.6', but just in case).  LP #1998258.
    1.9.1 (2022-11-29)
  - -----------------
  - Restore a deprecated alias for the '_must_decode' helper function, moved
    from 'pkginfo._compat.must_decode' to 'pkginfo.distribution._must_decode'
    in 1.90.
  - Repair unit tests broken by dropping Python 2.7 classifier.
    1.9.0 (2022-11-29)
  - -----------------
  - Drop support for Python 2.7.
  - Switch to use 'pytest' vs. 'nose', which doesn't support Python > 3.9.
    1.8.3 (2022-06-08)
  - -----------------
  - Specify supported Python versions in 'setup.py' using 'python_requires'.
    LP #1977981.
    1.8.2 (2021-12-01)
  - -----------------
  - Add fix for installed distributions with '__package__' set to an empty
    string. LP #1952946.
    1.8.1 (2021-11-19)
  - -----------------
  - Add 'MANIFEST.in' to ensure example files used by tests are included
    in source distributions.  LP #1951553.
    1.8.0 (2021-11-18)
  - -----------------
  - Support new standard metadata location for installed dists. LP #1865286.
  - Don't overwrite header-based 'description' with empty payload. LP #1885458.
  - Add support for Metadata-Version 2.2. LP #1928729.
  - Add support for uncompressed tarballs for sdists.  LP #1951457.
  - Add support for Python 3.10.
    1.7.1 (2021-07-09)
  - -----------------
  - Use Python3 to build docs, and fix doctest examples to use Python3-
    compatible syntax.  LP #1933322.
    1.7.0 (2021-01-16)
  - -----------------
  - Add support for Python 3.9.
  - Drop support for Python 3.5.
    1.6.1 (2020-10-26)
  - -----------------
  - Adjust test classifiers to match supported Python versions. LP #1901127.
    1.6.0 (2020-10-20)
  - -----------------
  - Add support for Python 3.8.
    LP #1869854.
  - Drop support for Python 3.4.
  - Update tests to match setuptools' change, no longer reporting metadata
    version for installed packages w/o explicit metadata.  LP #1870197.
* Sun Aug 16 2020 John Vandenberg <jayvdb@gmail.com>
- Remove unnecessary build dependency nose
* Wed Jun 19 2019 pgajdos@suse.com
- version update to 1.5.0.1
  * Fix broken 'sdist'. LP #1639585.
  * Fix 'console_scripts' entry point syntax. LP #1810734.
  * Add support for JSON output from the CLI.
  * Add support for installed wheels.  E.g., 'dist-info/' dirs.
  * Add support for Python 3.6 and 3.7.
  * Drop support for Python 3.3.
* Wed Dec 19 2018 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in summary.
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Sun May 20 2018 hpj@urpla.net
- fix failing tests with sed
- enable tests
* Sat May 19 2018 hpj@urpla.net
- Update to version 1.4.2
  - Use relative imports in pkginfo modules.  Supports vendoring of the
    package into setuptools.
  - Add support for ``Provides-Extra`` and ``Description-Content-Type`` fields.
    Per https://packaging.python.org/specifications/.  See:  PEP 566.
  - Remove support for old setuptools leaving ``PKG-INFO`` in the root of
    the project directory.
* Wed Apr 19 2017 toddrme2178@gmail.com
- Update to version 1.4.1
  * Packaging only change (invalid sdist bulit for 1.4.0).
- Update to version 1.4.0
  * Relicense under MIT license: the PSF license is not suitable for third-party libraries.
- Update to version 1.3.2
  * Packaging-only change (automate fix for wheel built for 1.3.1).
- Update to version 1.3.1
  * Packaging-only change (invalid wheel built for 1.3.0).
- Update to version 1.3.0
  * Update homepage URL to point to Launchpad, rather than PyPI.
  * Add support for building wheels.
  * Add support for Python 3.5.
  * Drop support for Python 2.6 and 3.2.
- Implement single-spec version.
* Tue Jun  2 2015 p.drouand@gmail.com
- Update to version 1.2.1
  * Add overlooked Trove classifier for Python 3.4.
- Changes from version 1.2 final
  * Add support for Python 3.4, PyPy3.
  * Add 100%% coverage for pkginfo.commandline module.
* Tue Feb  4 2014 speilicke@suse.com
- Initial version
